branch: externals/compat
commit a2967e97d7a23d00ff32094518e84599111fba82
Author: Daniel Mendler <m...@daniel-mendler.de>
Commit: Daniel Mendler <m...@daniel-mendler.de>

    Require cl-lib at compile time
---
 compat-27.el   | 1 -
 compat-macs.el | 6 ++++--
 2 files changed, 4 insertions(+), 3 deletions(-)

diff --git a/compat-27.el b/compat-27.el
index fa94a2073b..3a67e6ca2d 100644
--- a/compat-27.el
+++ b/compat-27.el
@@ -23,7 +23,6 @@
 ;;; Code:
 
 (eval-when-compile (load "compat-macs.el" nil t t))
-(eval-when-compile (require 'cl-lib))
 (compat-declare-version "27.1")
 
 ;;;; Defined in fns.c
diff --git a/compat-macs.el b/compat-macs.el
index 9dfe1234a1..a4de82dbe4 100644
--- a/compat-macs.el
+++ b/compat-macs.el
@@ -21,9 +21,11 @@
 
 ;;; Code:
 
 ;; We always require subr-x at compile since many functions have been moved
 ;; around.
 (require 'subr-x)
+(require 'cl-lib)
 
 (defvar compat--version nil
   "Version of the currently defined compatibility definitions.")
@@ -21,9 +21,11 @@
 ;;; Code:
 
-;; We always require subr-x at compile since many functions have been moved
-;; around.
+;; We always require subr-x at compile time for the fboundp check
+;; since definitions have been moved around. The cl-lib macros are
+;; needed by compatibility definitions.
 (require 'subr-x)

Reply via email to